PyXMake Developer Guide: PyXMake Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Namespaces | Variables
PyXMake Namespace Reference

PyXMake package for programmable build events on Linux and Windows. More...

## Namespaces
namespace | __install__
| Development code installation procedure for PyXMake.
namespace | __setenv__
| Initialize PyXMake environment for Python scripts executed directly from the command line.
namespace | API
| Contains all classes and functions to create a web application.
namespace | Build
| Module containing all relevant modules and scripts associated with the building process.
namespace | Plugin
| Imports additional features provided by and for 3rd party packages.
namespace | Tools
| Module containing basic functionalities defined for convenience.
namespace | VTL
| Module containing virtual testing & benchmark scripts.

## Variables
| PyXMakePath = os.path.dirname(os.path.abspath(__file__))
| Absolute system path to PyXMake.
| sys_path_backup = copy.deepcopy(sys.path)
| path
| key
str | expression = 'os.path.join(sitedir,*modname.split("."),"__init__.py")'
| Register development extension (if installed)
| candidate = candidate()
| spec = spec()
| module = importlib.util.module_from_spec(spec)

## Detailed Description

PyXMake package for programmable build events on Linux and Windows.

    PyXMake is a cross-plattform build tool for source files using either Intel Fortran,
    Py2X, a SSH connection or Doxygen to build a library or to automatically create a
    documentation.

    @note: PyXMake.__init__()
    Created on 20.03.2018

    @version: 1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @contributors:
          Falk Heinecke
          Sebastian Freund
          Andreas Schuster

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Authors
  Marc Garbade, Falk Heinecke, Sebastian Freund, Andreas Schuster

Date
  20.03.2018

Notes/Changes
  - Added documentation // mg 29.03.2018

## Variable Documentation

## ◆ candidate

PyXMake.candidate = candidate()

Definition at line 112 of file __init__.py.

## ◆ expression

str PyXMake.expression = 'os.path.join(sitedir,*modname.split("."),"__init__.py")'

Register development extension (if installed)

Definition at line 111 of file __init__.py.

## ◆ key

PyXMake.key

Definition at line 97 of file __init__.py.

## ◆ module

PyXMake.module = importlib.util.module_from_spec(spec)

Definition at line 118 of file __init__.py.

## ◆ path

PyXMake.path

Definition at line 97 of file __init__.py.

## ◆ PyXMakePath

PyXMake.PyXMakePath = os.path.dirname(os.path.abspath(__file__))

Absolute system path to PyXMake.

Definition at line 56 of file __init__.py.

## ◆ spec

PyXMake.spec = spec()

Definition at line 116 of file __init__.py.

## ◆ sys_path_backup

PyXMake.sys_path_backup = copy.deepcopy(sys.path)

Definition at line 92 of file __init__.py.